@@ -34,7 +34,7 @@ class ApiEndpoint:
         self.session = session
         self.api_url = api_url
 
-    def _make_url(self, endpoint: str = "") -> str:
+    def get_url(self, endpoint: str = "") -> str:
         return f"{self.root_url}/{self.api_url}{endpoint}"
 
 
