@@ -13,7 +13,7 @@ class DeviceMonitoring(ApiEndpoint):
 
     @api_call(MonitoringStatus)
     def is_monitored(self, device_id: str) -> MonitoringStatus:
-        return self.session.get(super()._make_url(f"/configuration/device/{device_id}/enabled"))
+        return self.session.get(self.get_url(f"/configuration/device/{device_id}/enabled"))
 
     @api_call(MonitoringDataResponse)
     def get_data_batch(self, device_id: str, lwm2m_url: str, start_time: datetime, end_time: Optional[datetime],
@@ -23,6 +23,6 @@ class DeviceMonitoring(ApiEndpoint):
         if end_time:
             params["timeRangeEnd"] = end_time.strftime(ISO_INSTANT_FORMAT)
         return self.session.get(
-            super()._make_url(f"/data/{device_id}/resourceUrl/{safe_lwm2m_url}"),
+            self.get_url(f"/data/{device_id}/resourceUrl/{safe_lwm2m_url}"),
             params=params
         )
